# Copyright © 2022 Idiap Research Institute <contact@idiap.ch>
#
# SPDX-License-Identifier: GPL-3.0-or-later


def _maker(protocol, resize_size=512, cc_size=512, RGB=False):
    from torchvision import transforms

    from ....data.montgomery import dataset as raw
    from ....data.transforms import ElasticDeformation, RemoveBlackBorders
    from .. import make_dataset as mk

    post_transforms = []
    if RGB:
        post_transforms = [
            transforms.Lambda(lambda x: x.convert("RGB")),
            transforms.ToTensor(),
        ]

    return mk(
        [raw.subsets(protocol)],
        [
            RemoveBlackBorders(),
            transforms.Resize(resize_size),
            transforms.CenterCrop(cc_size),
        ],
        [ElasticDeformation(p=0.8)],
        post_transforms,
    )
