# SPDX-FileCopyrightText: Copyright © 2023 Idiap Research Institute <contact@idiap.ch>
#
# SPDX-License-Identifier: GPL-3.0-or-later

"""TB-POC dataset for computer-aided diagnosis.

* Reference: [TB-POC-2018]_
* Original resolution (height x width or width x height): 2048 x 2500
* Split reference: none
* Stratified kfold protocol:

  * Training samples: 72% of TB and healthy CXR (including labels)
  * Validation samples: 18% of TB and healthy CXR (including labels)
  * Test samples: 10% of TB and healthy CXR (including labels)
"""

import importlib.resources

from ..dataset import JSONDataset
from ..loader import make_delayed

_protocols = [
    importlib.resources.files(__name__).joinpath("fold_0.json.bz2"),
    importlib.resources.files(__name__).joinpath("fold_1.json.bz2"),
    importlib.resources.files(__name__).joinpath("fold_2.json.bz2"),
    importlib.resources.files(__name__).joinpath("fold_3.json.bz2"),
    importlib.resources.files(__name__).joinpath("fold_4.json.bz2"),
    importlib.resources.files(__name__).joinpath("fold_5.json.bz2"),
    importlib.resources.files(__name__).joinpath("fold_6.json.bz2"),
    importlib.resources.files(__name__).joinpath("fold_7.json.bz2"),
    importlib.resources.files(__name__).joinpath("fold_8.json.bz2"),
    importlib.resources.files(__name__).joinpath("fold_9.json.bz2"),
]


def _raw_data_loader(sample):
    return dict(data=sample["data"], label=sample["label"])


def _loader(context, sample):
    # "context" is ignored in this case - database is homogeneous
    # we returned delayed samples to avoid loading all images at once
    return make_delayed(sample, _raw_data_loader, key=sample["filename"])


dataset = JSONDataset(
    protocols=_protocols,
    fieldnames=("filename", "label", "data"),
    loader=_loader,
)
"""Extended TB-POC dataset object."""
